# -*- coding: utf-8 -*-


from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Bounce',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('datetime', models.DateTimeField(null=True)),
                ('received', models.DateTimeField(auto_now_add=True)),
                ('filename', models.CharField(max_length=500)),
                ('status', models.CharField(max_length=500)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='List',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=40)),
                ('host', models.CharField(max_length=40)),
                ('subject', models.CharField(max_length=40)),
                ('description', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('state', models.IntegerField(default=2, choices=[(1, 'Production'), (2, 'Requested'), (3, 'On hold'), (4, 'Disabled')])),
                ('public', models.BooleanField(default=True, help_text='Publicly visible')),
                ('who_can_subscribe', models.IntegerField(default=1, choices=[(1, 'Everybody can subscribe'), (2, 'The admin must accept the request'), (3, 'No new subscription allowed')])),
                ('posting_from_subscriber', models.IntegerField(default=1, choices=[(1, 'Always accept'), (2, 'Moderate'), (3, 'Always deny')])),
                ('posting_from_external', models.IntegerField(default=2, verbose_name=b'Posting from non subscriber', choices=[(1, 'Always accept'), (2, 'Moderate'), (3, 'Always deny')])),
                ('mail_with_attachement', models.IntegerField(default=2, choices=[(1, 'Always accept'), (2, 'Moderate'), (3, 'Always deny')])),
                ('mail_as_bcc', models.IntegerField(default=2, choices=[(1, 'Always accept'), (2, 'Moderate'), (3, 'Always deny')])),
                ('probably_spam', models.IntegerField(default=2, choices=[(1, 'Always accept'), (2, 'Moderate'), (3, 'Always deny')])),
                ('archive_browsing', models.IntegerField(default=2, choices=[(1, 'Everybody can browse'), (2, 'Only members can browse'), (3, 'Nobody can browse')])),
                ('subscribers_list_visible', models.BooleanField(default=True, help_text='Can the subscribers browse the list of subscribers ?')),
                ('include_author_in_reply_to', models.BooleanField(default=True, help_text='Should we include the original author in the reply-to header ? (The mailing list address is always included)')),
                ('subject_tag', models.CharField(help_text='This will be added in the subject using brackets. You do NOT need to write the brackets yourself!', max_length=20, blank=True)),
                ('max_size', models.PositiveIntegerField(default=4194304)),
                ('subscribe', models.TextField(blank=True)),
                ('unsubscribe', models.TextField(blank=True)),
                ('header', models.TextField(blank=True)),
                ('trailer', models.TextField(blank=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OtherEmail',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('email', models.EmailField(max_length=75)),
                ('confirmed', models.BooleanField(default=False)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='OtherEmailKey',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('activation_key', models.CharField(max_length=40)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('otheremail', models.ForeignKey(to='main.OtherEmail', on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('bounces_count', models.PositiveIntegerField(default=0)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Subscription',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('started', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('option', models.IntegerField(default=1, choices=[(1, 'Normal'), (2, 'Digest'), (3, 'On Hold')])),
                ('moderator', models.BooleanField(default=False)),
                ('list', models.ForeignKey(to='main.List', on_delete=models.CASCADE)),
                ('profile', models.ForeignKey(to='main.Profile', on_delete=models.CASCADE)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Topic',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=40)),
                ('description', models.TextField()),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='subscription',
            unique_together=set([('profile', 'list')]),
        ),
        migrations.AddField(
            model_name='otheremail',
            name='profile',
            field=models.ForeignKey(related_name='secondary_emails', to='main.Profile', on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='list',
            name='owner',
            field=models.ForeignKey(related_name='own_lists', to='main.Profile', on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='list',
            name='topic',
            field=models.ManyToManyField(to='main.Topic', blank=True),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='list',
            unique_together=set([('name', 'host')]),
        ),
        migrations.AlterIndexTogether(
            name='list',
            index_together=set([('name', 'host')]),
        ),
        migrations.AddField(
            model_name='bounce',
            name='profile',
            field=models.ForeignKey(related_name='bounces_list', to='main.Profile', on_delete=models.CASCADE),
            preserve_default=True,
        ),
    ]
