#
# -*- coding: utf-8
# vim: set fileencoding=utf-8

#    Copyright (C) 2008-2011 Thomas Capricelli <orzel@freehackers.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Django
from django.urls import include, re_path, path
from django.views.generic.base import TemplateView
from django.contrib.auth import views as auth_views
from django.views.defaults import page_not_found

# project
from emailonlyauth.registrationbackend import ActivationView, RegistrationView
from main.views import myaccount

urlpatterns = [
    re_path(r'^register/$', page_not_found), # disable registering
]

urlpatterns = [
    # override templates
    path('login', auth_views.LoginView.as_view(), {'template_name': 'registration/login.html'}, name='login'),
    path('logout', auth_views.LogoutView.as_view(), {'template_name': 'registration/logout.html'}, name='logout'),

    # from django/contrib/auth/urls.py
    path('password_change/', auth_views.PasswordChangeView.as_view(), name='password_change'),
    path('password_change/done/', auth_views.PasswordChangeDoneView.as_view(), name='password_change_done'),

    # see https://docs.djangoproject.com/en/3.1/ref/contrib/admin/#adding-a-password-reset-feature
    path('password_reset/', auth_views.PasswordResetView.as_view(), name='password_reset',),
    path('password_reset/done/', auth_views.PasswordResetDoneView.as_view(), name='password_reset_done',),
    path('reset/<uidb64>/<token>/', auth_views.PasswordResetConfirmView.as_view(), name='password_reset_confirm',),
    path('reset/done/', auth_views.PasswordResetCompleteView.as_view(), name='password_reset_complete',),
]

urlpatterns += [
    re_path(r'^activate/complete/$',
        myaccount, # on success, does activation -> autologin -> go to main account page
        name='registration_activation_complete'),
    # Activation keys get matched by \w+ instead of the more specific
    # [a-fA-F0-9]{40} because a bad activation key should still get to the view;
    # that way it can return a sensible "invalid key" message instead of a
    # confusing 404.
    re_path(r'^activate/(?P<activation_key>\w+)/$',
        ActivationView.as_view(),
        name='registration_activate'),
    re_path(r'^register/$',
        RegistrationView.as_view(),
        name='registration_register'),
    re_path(r'^register/complete/$',
        TemplateView.as_view(template_name='registration/registration_complete.html'),
        name='registration_complete'),
    re_path(r'^register/closed/$',
        TemplateView.as_view(template_name='registration/registration_closed.html'),
        name='registration_disallowed'),
]

# vim: ai ts=4 sts=4 et sw=4
