# -*- coding: utf-8
# vim: set fileencoding=utf-8

#    Copyright (C) 2008-2011 Thomas Capricelli <orzel@freehackers.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Django
from django.urls import include, re_path, path
from django.contrib import admin
from django.conf import settings
from django.contrib.auth import views as auth_views

# Project
from main import views

handler500 = 'main.views.server_error'

LIST_REGEXP = r'([@\-\.\w]+)'

urlpatterns = [
    re_path(r'^accounts/', include('main.urls')),
    path('admin/', admin.site.urls),
]

urlpatterns += [
    re_path(r'^credits$', views.credits, name='credits' ),
    re_path(r'^myaccount/$', views.myaccount, name='myaccount'),
    re_path(r'^list/'+LIST_REGEXP+r'/archives/(\d{4})/(\d{1,2})/(.*)$', views.list_archives_month, name="list_archives_month"),
    re_path(r'^list/'+LIST_REGEXP+r'/archives/(\d{4})/$', views.list_archives_year, name="list_archives_year"),
    re_path(r'^list/'+LIST_REGEXP+r'/archives/$', views.list_archives, name="list_archives"),
    re_path(r'^list/'+LIST_REGEXP+r'/subscribers/$', views.list_subscribers, name="list_subscribers"),
    re_path(r'^list/'+LIST_REGEXP+r'/subscribe/$', views.list_subscribe, name="list_subscribe"),
    re_path(r'^list/'+LIST_REGEXP+r'/unsubscribe/$', views.list_unsubscribe, name="list_unsubscribe"),
    re_path(r'^list/'+LIST_REGEXP+r'/manage/$', views.list_manage, name="list_manage"),
    re_path(r'^list/'+LIST_REGEXP+r'/$', views.display_list_info, name="display_list_info"),
    re_path(r'^topic/(.*)/$', views.display_topic_info, name="display_topic_info"),
    re_path(r'^$', views.main, name="main"),
]
urlpatterns += [
    re_path(r'^secondary_email/(\d+)/remove/$', views.remove_secondary_email, name="remove_secondary_email"),
    re_path(r'^secondary_email/(\d+)/send_confirmation/$', views.confirm_secondary_email, name="confirm_secondary_email"),
    re_path(r'^secondary_email/(\d+)/switch/$', views.switch_secondary_email, name="switch_secondary_email"),
    re_path(r'^secondary_email/activate/(?P<activation_key>\w+)/$', views.activate_secondary_email, name="activate_secondary_email"),
]

if settings.DEBUG:
    from os.path import join
    from django.views.static import serve
    urlpatterns += [
        re_path(r'^media/(?P<path>.*)$', serve, { 'document_root': settings.MEDIA_ROOT, }),
        re_path(r'^favicon.ico$', serve, { 'path': 'favicon.ico', 'document_root': join(settings.BASE_DIR, 'static'), }),
        re_path(r'^robots.txt$', serve, { 'path': 'robots.txt', 'document_root': join(settings.BASE_DIR, 'static'), }),
        re_path(r'^500/$', views.server_error),
    ]

# vim: ai ts=4 sts=4 et sw=4
